CoapConfig class

Allows for configuring the behavior of CoAP clients and servers.

Annotations
  • @immutable

Constructors

CoapConfig({int port = 5683, int securePort = 5684, int? blocksize, bool allowMulticastDiscovery = false, Duration multicastDiscoveryTimeout = const Duration(minutes: 60), String? dtlsCiphers, List<Certificate> rootCertificates = const [], bool dtlsWithTrustedRoots = true, bool dtlsVerify = true, int? openSslSecurityLevel})
Creates a new CoapConfig object.
const

Properties

allowMulticastDiscovery → bool
Indicates if multicast should be available for discovery.
final
blocksize → int?
The preferred block size for blockwise transfer.
final
dtlsCiphers → String?
Can be used to specify the Ciphers that should be used by OpenSSL.
final
dtlsVerify → bool
Whether certificates should be verified by OpenSSL.
final
dtlsWithTrustedRoots → bool
Whether OpenSSL should be used with trusted Root Certificates.
final
hashCode → int
The hash code for this object.
no setterinherited
multicastDiscoveryTimeout → Duration
The duration after which multicast discovery is supposed to time out.
final
openSslSecurityLevel → int?
Security level override for using DTLS with OpenSSL.
final
port → int
The port number used by a client or server. Defaults to 5683.
final
rootCertificates → List<Certificate>
List of custom root certificates to use with OpenSSL.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securePort → int
The coaps port number used by a client or server. Defaults to 5684.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited