Action class final

Class representing an Action Affordance in a Thing Description.

Inheritance
Annotations
  • @immutable

Constructors

Action({required List<Form> forms, String? title, Map<String, String>? titles, String? description, Map<String, String>? descriptions, Map<String, DataSchema>? uriVariables, Map<String, dynamic> additionalFields = const {}, bool safe = false, bool idempotent = false, bool? synchronous, DataSchema? input, DataSchema? output})
Creates a new Action from a List of forms.
const
Action.fromJson(Map<String, dynamic> json, PrefixMapping prefixMapping)
Creates a new Action from a json object.
factory

Properties

additionalFields → Map<String, dynamic>
Additional fields that could not be deserialized as class members.
finalinherited
atType → List<String>?
/// JSON-LD keyword to label the object with semantic tags (or types).
finalinherited
description → String?
The default description of this InteractionAffordance.
finalinherited
descriptions → Map<String, String>?
Multi-language descriptions of this InteractionAffordance.
finalinherited
forms → List<Form>
The basic forms which can be used for interacting with this resource.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
idempotent → bool
Indicates whether the Action is idempotent (=true) or not.
final
input → DataSchema?
The schema of the input data this Action accepts.
final
output → DataSchema?
The schema of the output data this Action produces.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
safe → bool
Signals if the Action is safe (=true) or not.
final
synchronous → bool?
Indicates whether the action is synchronous (=true) or not.
final
title → String?
The default title of this InteractionAffordance.
finalinherited
titles → Map<String, String>?
Multi-language titles of this InteractionAffordance.
finalinherited
uriVariables → Map<String, DataSchema>?
URI template variables as defined in RFC 6570.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts this InteractionAffordance to a Map resembling a JSON object.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited