AdditionalExpectedResponse class

Communication metadata describing the expected response message for the primary response.

Annotations
  • @immutable

Constructors

AdditionalExpectedResponse(String contentType, {String? schema, bool success = false, Map<String, dynamic> additionalFields = const {}})
Constructs a new AdditionalExpectedResponse object from a contentType.
const
AdditionalExpectedResponse.fromJson(Map<String, dynamic> json, String formContentType, PrefixMapping prefixMapping)
Creates an AdditionalExpectedResponse from a json object.
factory

Properties

additionalFields → Map<String, dynamic>
Any other additional field will be included in this Map.
final
contentType → String
The contentType of this AdditionalExpectedResponse object.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schema → String?
Used to define the output data schema for an additional response if it differs from the default output data schema.
final
success → bool
Signals if an additional response should not be considered an error.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts this class object into a JSON value.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override