AugmentedForm class final

A Form augmented with information from its associated _thingDescription and _interactionAffordance.

Implemented types
Annotations
  • @immutable

Constructors

AugmentedForm(Form _form, InteractionAffordance _interactionAffordance, ThingDescription _thingDescription, Map<String, Object>? _userProvidedUriVariables)
Creates a new augmented Form.
const

Properties

additionalFields → Map<String, dynamic>
Additional fields collected during the parsing of a JSON object.
no setteroverride
additionalResponses → List<AdditionalExpectedResponse>?
This optional term can be used if additional expected responses are possible, e.g. for error reporting.
no setteroverride
contentCoding → String?
The content coding supported by this Form.
no setteroverride
contentType → String
The contentType supported by this Form.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
href → Uri
The href pointing to the resource.
no setteroverride
op → List<OperationType>
The operation types supported by this Form.
no setteroverride
response → ExpectedResponse?
The response a consumer can expect from interacting with this Form.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scopes → List<String>?
A list of OAuth2 scopes that are supposed to be used with this Form.
no setteroverride
security → List<String>
The list of security definitions applied to this Form.
no setteroverride
securityDefinitions → List<SecurityScheme>
The computed List of SecuritySchemes associated with this form.
no setter
subprotocol → String?
The subprotocol that is used with this Form.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts this class object into a JSON value.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited