AutoSecurityScheme class final

An automatic security configuration identified by the vocabulary term auto.

Inheritance

Constructors

AutoSecurityScheme({String? description, Map<String, String>? descriptions, Uri? proxy, List<String>? jsonLdType, Map<String, dynamic> additionalFields = const {}})
Constructor.
const
AutoSecurityScheme.fromJson(Map<String, dynamic> json, PrefixMapping prefixMapping, Set<String> parsedFields)
Creates an AutoSecurityScheme from a json object.
factory

Properties

additionalFields → Map<String, dynamic>
Additional fields collected during the parsing of a JSON object.
finalinherited
description → String?
The default description of this SecurityScheme.
finalinherited
descriptions → Map<String, String>?
A Map of multi-language descriptions.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
jsonLdType → List<String>?
A List of JSON-LD @type annotations.
finalinherited
proxy → Uri?
Uri of the proxy server this security configuration provides access to.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheme → String
The actual security scheme identifier.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts this class object into a JSON value.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited