BasicCredentials class final

Credentials used for the BasicSecurityScheme.

Provides an unencrypted username and password combination.

Inheritance

Constructors

BasicCredentials(String username, String password)
Constructor.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
password → String
The password associated with these BasicCredentials.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
username → String
The username associated with these BasicCredentials.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited