BasicSecurityScheme class final

Basic Authentication security configuration identified by the Vocabulary Term basic.

Inheritance

Constructors

BasicSecurityScheme({String? name, String in_ = _defaultInValue, String? description, Map<String, String>? descriptions, Uri? proxy, List<String>? jsonLdType, Map<String, dynamic> additionalFields = const {}})
Constructor.
const
BasicSecurityScheme.fromJson(Map<String, dynamic> json, PrefixMapping prefixMapping, Set<String> parsedFields)
Creates a BasicSecurityScheme from a json object.
factory

Properties

additionalFields → Map<String, dynamic>
Additional fields collected during the parsing of a JSON object.
finalinherited
description → String?
The default description of this SecurityScheme.
finalinherited
descriptions → Map<String, String>?
A Map of multi-language descriptions.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
in_ → String
Specifies the location of security authentication information.
final
jsonLdType → List<String>?
A List of JSON-LD @type annotations.
finalinherited
name → String?
Name for query, header, cookie, or uri parameters.
final
proxy → Uri?
Uri of the proxy server this security configuration provides access to.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheme → String
The actual security scheme identifier.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts this class object into a JSON value.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited