ComboSecurityScheme class final

A combination of other security schemes identified by the Vocabulary Term combo (i.e., "scheme": "combo").

Inheritance

Constructors

ComboSecurityScheme({List<String>? allOf, List<String>? oneOf, String? description, Map<String, String>? descriptions, Uri? proxy, List<String>? jsonLdType, Map<String, dynamic> additionalFields = const {}})
Constructor.
const
ComboSecurityScheme.fromJson(Map<String, dynamic> json, PrefixMapping prefixMapping, Set<String> parsedFields)
Creates a ComboSecurityScheme from a json object.
factory

Properties

additionalFields → Map<String, dynamic>
Additional fields collected during the parsing of a JSON object.
finalinherited
allOf → List<String>?
Array of two or more strings identifying other named security scheme definitions, all of which must be satisfied for access.
final
description → String?
The default description of this SecurityScheme.
finalinherited
descriptions → Map<String, String>?
A Map of multi-language descriptions.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
jsonLdType → List<String>?
A List of JSON-LD @type annotations.
finalinherited
oneOf → List<String>?
Array of two or more strings identifying other named security scheme definitions, any one of which, when satisfied, will allow access.
final
proxy → Uri?
Uri of the proxy server this security configuration provides access to.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheme → String
The actual security scheme identifier.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts this class object into a JSON value.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited