CoreLinkFormatConfiguration class final

Configures discovery using the CoRE link format (RFC 6690).

Inheritance
Annotations
  • @experimental

Constructors

CoreLinkFormatConfiguration(Uri baseUrl, {DiscoveryType discoveryType = DiscoveryType.thing, String coreLinkFormatPath = "/.well-known/core"})
Instantiates a new CoreLinkFormatConfiguration object.

Properties

discoveryType → DiscoveryType
Indicates whether this configuration is used for discovering Things or Thing Description Directories.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri → Uri
Points to the CoRE Link Format resource.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited