DiscoveryContent class

Content specific for discovery.

Mostly used for being able to convert results from multicast discovery to unicast discovery operations.

Inheritance

Constructors

DiscoveryContent(String type, Stream<List<int>> body, Uri sourceUri)
Creates a new Content object from a media type, a body, and an optional sourceUri.
DiscoveryContent.fromContent(Content content, Uri sourceUri)
Creates a new DiscoveryContent object from regular Content and a sourceUri.

Properties

body → Stream<List<int>>
The payload as a byte Stream.
finalinherited
byteBuffer → Future<ByteBuffer>
Converts the body of the content to a ByteBuffer asynchronously.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceUri → Uri
The source of this DiscoveryContent.
final
type → String
The media type corresponding with this Content object.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toByteList() → Future<List<int>>
Converts the body of this Content to a List of bytes asynchronously.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited