DnsSdDConfiguration class final

A DiscoveryConfiguration for performing DNS-based Service Discovery (RFC 6763) to obtain Thing Descriptions.

Inheritance

Constructors

DnsSdDConfiguration({String domainName = ".local", DiscoveryType discoveryType = DiscoveryType.thing, ProtocolType protocolType = ProtocolType.tcp})
Instantiates a new DnsSdDConfiguration, indicating the protocolType and discoveryType.
const

Properties

discoveryType → DiscoveryType
Indicates whether this configuration is used for discovering Things or Thing Description Directories.
finalinherited
domainName → String
The domain name that will be used for DNS-based Service Discovery.
final
hashCode → int
The hash code for this object.
no setterinherited
protocolType → ProtocolType
Indicates whether TCP-based or a UDP-based WoT services be will be discovered.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited