Event class

Class representing an Event Affordance in a Thing Description.

Inheritance

Constructors

Event({required List<Form> forms, String? title, Map<String, String>? titles, String? description, Map<String, String>? descriptions, Map<String, DataSchema>? uriVariables, DataSchema? subscription, DataSchema? data, DataSchema? cancellation, Map<String, dynamic> additionalFields = const {}})
Creates a new Event from a List of forms.
const
Event.fromJson(Map<String, dynamic> json, PrefixMapping prefixMapping)
Creates a new Event from a json object.
factory

Properties

additionalFields → Map<String, dynamic>
Additional fields that could not be deserialized as class members.
finalinherited
atType → List<String>?
/// JSON-LD keyword to label the object with semantic tags (or types).
finalinherited
cancellation → DataSchema?
Defines any data that needs to be passed to cancel a subscription.
final
data → DataSchema?
Defines the DataSchema of the Event instance messages pushed by the Thing.
final
description → String?
The default description of this InteractionAffordance.
finalinherited
descriptions → Map<String, String>?
Multi-language descriptions of this InteractionAffordance.
finalinherited
forms → List<Form>
The basic forms which can be used for interacting with this resource.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscription → DataSchema?
Defines data that needs to be passed upon subscription.
final
title → String?
The default title of this InteractionAffordance.
finalinherited
titles → Map<String, String>?
Multi-language titles of this InteractionAffordance.
finalinherited
uriVariables → Map<String, DataSchema>?
URI template variables as defined in RFC 6570.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts this class object into a JSON value.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited