ExpectedResponse class

Communication metadata describing the expected response message for the primary response.

Annotations
  • @immutable

Constructors

ExpectedResponse(String contentType, {Map<String, dynamic> additionalFields = const {}})
Constructs a new ExpectedResponse object from a contentType.
const
ExpectedResponse.fromJson(Map<String, dynamic> json, PrefixMapping prefixMapping)
Creates an ExpectedResponse from a json object.
factory

Properties

additionalFields → Map<String, dynamic>
Any other additional field will be included in this Map.
final
contentType → String
The contentType of this ExpectedResponse object.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts this class object into a JSON value.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited