Form class

Contains the information needed for performing interactions with a Thing.

Implementers
Annotations
  • @immutable

Constructors

Form(Uri href, {String contentType = _defaultContentType, String? contentCoding, String? subprotocol, List<String>? security, List<OperationType>? op, List<String>? scopes, ExpectedResponse? response, List<AdditionalExpectedResponse>? additionalResponses, Map<String, dynamic>? additionalFields})
Creates a new Form object.
Form.fromJson(Map<String, dynamic> json, PrefixMapping prefixMapping)
Creates a new Form from a json object.
factory

Properties

additionalFields → Map<String, dynamic>
Additional fields collected during the parsing of a JSON object.
final
additionalResponses → List<AdditionalExpectedResponse>?
This optional term can be used if additional expected responses are possible, e.g. for error reporting.
final
contentCoding → String?
The content coding supported by this Form.
final
contentType → String
The contentType supported by this Form.
final
hashCode → int
The hash code for this object.
no setterinherited
href → Uri
The href pointing to the resource.
final
op → List<OperationType>?
The operation types supported by this Form.
final
response → ExpectedResponse?
The response a consumer can expect from interacting with this Form.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scopes → List<String>?
A list of OAuth2 scopes that are supposed to be used with this Form.
final
security → List<String>?
The list of security definitions applied to this Form.
final
subprotocol → String?
The subprotocol that is used with this Form.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts this class object into a JSON value.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited