InteractionAffordance class sealed

Base class for Interaction Affordances (Properties, Actions, and Events).

Implementers
Annotations
  • @immutable

Properties

additionalFields → Map<String, dynamic>
Additional fields that could not be deserialized as class members.
final
atType → List<String>?
/// JSON-LD keyword to label the object with semantic tags (or types).
final
description → String?
The default description of this InteractionAffordance.
final
descriptions → Map<String, String>?
Multi-language descriptions of this InteractionAffordance.
final
forms → List<Form>
The basic forms which can be used for interacting with this resource.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
The default title of this InteractionAffordance.
final
titles → Map<String, String>?
Multi-language titles of this InteractionAffordance.
final
uriVariables → Map<String, DataSchema>?
URI template variables as defined in RFC 6570.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts this class object into a JSON value.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited