InteractionOutput class abstract interface

Exposes the data obtained by Thing interactions.

See WoT Scripting API Specification, Section 7.2.

Properties

data → Stream<List<int>>?
The raw payload of the InteractionOutput as a Byte Stream.
no setter
dataUsed → bool
Indicates if the data has already been retrieved from this InteractionOutput.
no setter
form → Form?
The Form corresponding to this InteractionOutput.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schema → DataSchema?
An optional DataSchema which can be used for validating the InteractionOutput.
no setter

Methods

arrayBuffer() → Future<ByteBuffer>
Asynchronously creates a ByteBuffer representation of the value of of the InteractionOutput.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
value() → Future<Object?>
The parsed value of the InteractionOutput.

Operators

operator ==(Object other) → bool
The equality operator.
inherited