NotReadableException class final

Indicates that an I/O read operation failed.

Corresponds with the Web IDL exception type NotReadableError.

Inheritance

Constructors

NotReadableException(String message)
Instantiates a new NotReadableException with the given message.
const

Properties

exceptionType → String
The name of this Exception that will appear in the error message log.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
message → String
The error message of this DartWotException.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited