OAuth2Credentials class final

Inheritance

Constructors

OAuth2Credentials({String? secret, String? credentialsJson})
Constructor.
const

Properties

credentialsJson → String?
A JSON string representation of OAuth2 credentials.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secret → String?
The optional secret for these OAuth2Credentials.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited