Property class

Class representing a Property Affordance in a Thing Description.

Inheritance
Implemented types
Annotations
  • @immutable

Constructors

Property({required List<Form> forms, required DataSchema dataSchema, Map<String, DataSchema>? uriVariables, Map<String, dynamic> additionalFields = const {}, bool observable = _defaultObservableValue})
Default constructor that creates a Property from a List of forms.
const
Property.fromJson(Map<String, dynamic> json, PrefixMapping prefixMapping)
Creates a new Property from a json object.
factory

Properties

additionalFields → Map<String, dynamic>
Additional fields that could not be deserialized as class members.
no setteroverride
atType → List<String>?
/// JSON-LD keyword to label the object with semantic tags (or types).
no setteroverride
constant → Object?
A constant value.
no setteroverride
contentEncoding → String?
Specifies the encoding used to store the contents, as specified in RFC 2045 (Section 6.1) and RFC 4648.
no setteroverride
contentMediaType → String?
Specifies the MIME type of the contents of a string value, as described in RFC 2046.
no setteroverride
dataSchema → DataSchema
The internal DataSchema this property is based on.
final
defaultValue → Object?
A default value if no actual value is set.
no setteroverride
description → String?
The default description of this InteractionAffordance.
no setteroverride
descriptions → Map<String, String>?
Multi-language descriptions of this InteractionAffordance.
no setteroverride
enumeration → List<Object?>?
Restricted set of values provided as a List.
no setteroverride
exclusiveMaximum → num?
Specifies a maximum numeric value, representing an exclusive upper limit.
no setteroverride
exclusiveMinimum → num?
Specifies a minimum numeric value, representing an exclusive lower limit.
no setteroverride
format → String?
Allows validation based on a format pattern.
no setteroverride
forms → List<Form>
The basic forms which can be used for interacting with this resource.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
items → List<DataSchema>?
Used to define the characteristics of an array.
no setteroverride
maximum → num?
Specifies a maximum numeric value, representing an inclusive upper limit.
no setteroverride
maxItems → int?
Defines the maximum number of items that have to be in an array.
no setteroverride
maxLength → int?
Specifies the maximum length of a string.
no setteroverride
minimum → num?
Specifies a minimum numeric value, representing an inclusive lower limit.
no setteroverride
minItems → int?
Defines the minimum number of items that have to be in an array.
no setteroverride
minLength → int?
Specifies the minimum length of a string.
no setteroverride
multipleOf → num?
Specifies the multipleOf value number. The value must strictly greater than 0.
no setteroverride
observable → bool
A hint that indicates whether Servients hosting the Thing and Intermediaries should provide a Protocol Binding that supports the observeproperty and unobserveproperty operations for this Property.
final
oneOf → List<DataSchema>?
Allows the specification of multiple DataSchemas for validation.
no setteroverride
pattern → String?
Provides a regular expression to express constraints of the string value.
no setteroverride
properties → Map<String, DataSchema>?
Data schema nested definitions in an object.
no setteroverride
readOnly → bool
Indicates if a value is read only.
no setteroverride
required → List<String>?
Defines which members of the object type are mandatory, i.e. which members are mandatory in the payload that is to be sent (e.g. input of invokeaction, writeproperty) and what members will be definitely delivered in the payload that is being received (e.g. output of invokeaction, readproperty).
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
The default title of this InteractionAffordance.
no setteroverride
titles → Map<String, String>?
Multi-language titles of this InteractionAffordance.
no setteroverride
type → String?
JSON-based data type compatible with JSON Schema.
no setteroverride
unit → String?
The unit of the value.
no setteroverride
uriVariables → Map<String, DataSchema>?
URI template variables as defined in RFC 6570.
finalinherited
writeOnly → bool
Indicates if a value is write only.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts this class object into a JSON value.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited