ProtocolClientFactory class abstract interface

Base class for a factory that produces ProtocolClients.

Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemes → Set<String>
The protocol schemes support of the clients this factory produces.
no setter

Methods

createClient() → ProtocolClient
Creates a new ProtocolClient with that supports one or more of the given schemes.
destroy() → bool
Destroys this ProtocolClientFactory.
init() → bool
Initializes this ProtocolClientFactory.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
supportsOperation(OperationType operationType, String? subprotocol) → bool
Indicates whether this ProtocolClientFactory supports a given operationType and subprotocol.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited