ProtocolServer class abstract interface

Base class for a Protocol Server.

Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
port → int
The port number used by this Server.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheme → String
The protocol scheme associated with this server.
no setter

Methods

expose(ExposedThing thing) → Future<void>
Exposes a thing.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start([ServerSecurityCallback? serverSecurityCallback]) → Future<void>
Starts the server. Accepts a callback for retrieving a Map of credentials for ExposedThings at runtime.
stop() → Future<void>
Stops the server.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited