ProtocolSubscription class abstract base

Base class for implementations of the Subscription interface.

Implemented types

Constructors

ProtocolSubscription(void _complete())
Instantiates a new ProtocolSubscription.

Properties

active → bool
Denotes whether the subscription is active, i.e. it is not stopped because of an error or because of invocation of the stop method.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
stop({int? formIndex, Map<String, Object>? uriVariables, Object? data}) → Future<void>
Stops delivering notifications for the subscription.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited