PskCredentials class final

Inheritance

Constructors

PskCredentials({required Uint8List preSharedKey, required Uint8List identity})
Constructor.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
identity → Uint8List
The identity associated with these PskCredentials.
final
preSharedKey → Uint8List
The preSharedKey associated with these PskCredentials.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited