Servient class abstract

A software stack that implements the WoT building blocks.

A Servient can host and expose Things and/or host Consumers that consume Things. Servients can support multiple Protocol Bindings to enable interaction with different IoT platforms.

Constructors

Servient.create({List<ProtocolClientFactory>? clientFactories, ServerSecurityCallback? serverSecurityCallback, ContentSerdes? contentSerdes})
Creates a new Servient.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addClientFactory(ProtocolClientFactory clientFactory) → void
Adds a new clientFactory to this Servient.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeClientFactory(String scheme) → ProtocolClientFactory?
Removes a ProtocolClientFactory matching the given scheme from this Servient, if present.
shutdown() → Future<void>
Closes this Servient and cleans up all resources.
start() → Future<WoT>
Starts this Servient and returns a scripting_api.WoT runtime object.
startClientFactories() → WoT
Synchronously starts this Servient and returns a scripting_api.WoT runtime object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited