Subscription class abstract interface

Represents a subscription to Property change and Event interactions.

Implementers

Properties

active → bool
Denotes whether the subscription is active, i.e. it is not stopped because of an error or because of invocation of the stop method.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
stop({int? formIndex, Map<String, Object>? uriVariables, Object? data}) → Future<void>
Stops delivering notifications for the subscription.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited