ThingDescription class

Represents a WoT Thing Description.

Annotations
  • @immutable

Constructors

ThingDescription({required Context context, required String title, required List<String> security, required Map<String, SecurityScheme> securityDefinitions, Map<String, String>? titles, List<String>? atType, String? id, Map<String, String>? descriptions, DateTime? created, DateTime? modified, Uri? support, Uri? base, Map<String, Property>? properties, Map<String, Action>? actions, Map<String, Event>? events, List<Link>? links, List<Form>? forms, List<Uri>? profile, Map<String, DataSchema>? schemaDefinitions, Map<String, dynamic>? additionalFields, String? description, VersionInfo? version, Map<String, DataSchema>? uriVariables})
Creates a new Thing Description object.
const
ThingDescription.fromJson(Map<String, dynamic> json)
Creates a ThingDescription from a json object.
factory
ThingDescription.fromThingModel(ThingModel thingModel)
Creates a ThingDescription from a ThingModel.
factory

Properties

actions → Map<String, Action>?
A Map of Action Affordances.
final
additionalFields → Map<String, dynamic>?
Additional fields collected during the parsing of a JSON object.
final
atType → List<String>?
JSON-LD keyword to label the object with semantic tags (or types).
final
base → Uri?
The base address of this ThingDescription. Might be null.
final
context → Context
The JSON-LD @context, represented by a List of ContextEntrys.
final
created → DateTime?
Provides information when the TD instance was created.
final
description → String?
The description of this ThingDescription.
final
descriptions → Map<String, String>?
A Map of multi-language descriptions.
final
events → Map<String, Event>?
A Map of Event Affordances.
final
forms → List<Form>?
Set of form hypermedia controls that describe how an operation can be performed.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The id of this ThingDescription. Might be null.
final
identifier → String
Determines the id of this ThingDescription.
no setter
A List of Links.
final
modified → DateTime?
Provides information when the TD instance was last modified.
final
prefixMapping → PrefixMapping
Contains the values of the @context for CURIE expansion.
no setter
profile → List<Uri>?
Indicates the WoT Profile mechanisms followed by this Thing Description and the corresponding Thing implementation.
final
properties → Map<String, Property>?
A Map of Property Affordances.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemaDefinitions → Map<String, DataSchema>?
Set of named data schemas.
final
security → List<String>
A List of the securityDefinitions that are used as the default.
final
securityDefinitions → Map<String, SecurityScheme>
A map of SecuritySchemes that can be used for secure communication.
final
support → Uri?
Provides information about the TD maintainer as URI scheme (e.g., mailto RFC 6068, tel RFC 3966, https RFC 9112).
final
title → String
The title of this ThingDescription.
final
titles → Map<String, String>?
A Map of multi-language titles.
final
uriVariables → Map<String, DataSchema>?
URI template variables as defined in RFC 6570.
final
version → VersionInfo?
Provides version information.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts this ThingDescription to a Map resembling a JSON object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited