ThingDiscoveryProcess class abstract interface

Provides the properties and methods controlling the discovery process, and returning the results.

Implemented types

Properties

done → bool
true if the discovery has been stopped or completed with no more results to report.
no setter
error → Exception?
Represents the last error that occurred during the discovery process.
no setter
first → Future<ThingDescription>
The first element of this stream.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isBroadcast → bool
Whether this stream is a broadcast stream.
no setterinherited
isEmpty → Future<bool>
Whether this stream contains any elements.
no setterinherited
last → Future<ThingDescription>
The last element of this stream.
no setterinherited
length → Future<int>
The number of elements in this stream.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
single → Future<ThingDescription>
The single element of this stream.
no setterinherited
thingFilter → ThingFilter?
Optional filter that can applied during the discovery process.
no setter

Methods

any(bool test(ThingDescription element)) → Future<bool>
Checks whether test accepts any element provided by this stream.
inherited
asBroadcastStream({void onListen(StreamSubscription<ThingDescription> subscription)?, void onCancel(StreamSubscription<ThingDescription> subscription)?}) → Stream<ThingDescription>
Returns a multi-subscription stream that produces the same events as this.
inherited
asyncExpand<E>(Stream<E>? convert(ThingDescription event)) → Stream<E>
Transforms each element into a sequence of asynchronous events.
inherited
asyncMap<E>(FutureOr<E> convert(ThingDescription event)) → Stream<E>
Creates a new stream with each data event of this stream asynchronously mapped to a new event.
inherited
cast<R>() → Stream<R>
Adapt this stream to be a Stream<R>.
inherited
contains(Object? needle) → Future<bool>
Returns whether needle occurs in the elements provided by this stream.
inherited
distinct([bool equals(ThingDescription previous, ThingDescription next)?]) → Stream<ThingDescription>
Skips data events if they are equal to the previous data event.
inherited
drain<E>([E? futureValue]) → Future<E>
Discards all data on this stream, but signals when it is done or an error occurred.
inherited
elementAt(int index) → Future<ThingDescription>
Returns the value of the indexth data event of this stream.
inherited
every(bool test(ThingDescription element)) → Future<bool>
Checks whether test accepts all elements provided by this stream.
inherited
expand<S>(Iterable<S> convert(ThingDescription element)) → Stream<S>
Transforms each element of this stream into a sequence of elements.
inherited
firstWhere(bool test(ThingDescription element), {ThingDescription orElse()?}) → Future<ThingDescription>
Finds the first element of this stream matching test.
inherited
fold<S>(S initialValue, S combine(S previous, ThingDescription element)) → Future<S>
Combines a sequence of values by repeatedly applying combine.
inherited
forEach(void action(ThingDescription element)) → Future<void>
Executes action on each element of this stream.
inherited
handleError(Function onError, {bool test(dynamic error)?}) → Stream<ThingDescription>
Creates a wrapper Stream that intercepts some errors from this stream.
inherited
join([String separator = ""]) → Future<String>
Combines the string representation of elements into a single string.
inherited
lastWhere(bool test(ThingDescription element), {ThingDescription orElse()?}) → Future<ThingDescription>
Finds the last element in this stream matching test.
inherited
listen(void onData(ThingDescription event)?, {Function? onError, void onDone()?, bool? cancelOnError}) → StreamSubscription<ThingDescription>
Adds a subscription to this stream.
inherited
map<S>(S convert(ThingDescription event)) → Stream<S>
Transforms each element of this stream into a new stream event.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pipe(StreamConsumer<ThingDescription> streamConsumer) → Future
Pipes the events of this stream into streamConsumer.
inherited
reduce(ThingDescription combine(ThingDescription previous, ThingDescription element)) → Future<ThingDescription>
Combines a sequence of values by repeatedly applying combine.
inherited
singleWhere(bool test(ThingDescription element), {ThingDescription orElse()?}) → Future<ThingDescription>
Finds the single element in this stream matching test.
inherited
skip(int count) → Stream<ThingDescription>
Skips the first count data events from this stream.
inherited
skipWhile(bool test(ThingDescription element)) → Stream<ThingDescription>
Skip data events from this stream while they are matched by test.
inherited
stop() → Future<void>
Stops the discovery process.
take(int count) → Stream<ThingDescription>
Provides at most the first count data events of this stream.
inherited
takeWhile(bool test(ThingDescription element)) → Stream<ThingDescription>
Forwards data events while test is successful.
inherited
timeout(Duration timeLimit, {void onTimeout(EventSink<ThingDescription> sink)?}) → Stream<ThingDescription>
Creates a new stream with the same events as this stream.
inherited
toList() → Future<List<ThingDescription>>
Collects all elements of this stream in a List.
inherited
toSet() → Future<Set<ThingDescription>>
Collects the data of this stream in a Set.
inherited
toString() → String
A string representation of this object.
inherited
transform<S>(StreamTransformer<ThingDescription, S> streamTransformer) → Stream<S>
Applies streamTransformer to this stream.
inherited
where(bool test(ThingDescription element)) → Stream<ThingDescription>
Creates a new stream from this stream that discards some elements.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited