done property
bool
get
done
true if the discovery has been stopped or completed with no more results
to report.
Implementation
bool get done;
true if the discovery has been stopped or completed with no more results
to report.
bool get done;