UriMapContextEntry class final

Key-value @context entry that contains a uri as its value.

Inheritance

Constructors

UriMapContextEntry(String key, Uri uri)
Creates a new UriMapContextEntry from a key and a uri.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → String
The key of this @context entry.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri → Uri
The URI that the key of this @context entry points to.
final
value → String
The value of this @context entry.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited